float4x4 matWorld;
float4x4 matView;
float4x4 matProj;
float4x4 matTangent;
float4x4 matWorldViewProj;

float4 vecFog;
float4 vecViewPos;
float4 vecTime;
float4 vecColor;
float4 vecSkill1;

float4 vecSkill41; // Wind_X, Wind_Y, Ripple, Scale

texture mtlSkin1;
texture entSkin1;

sampler sReflectTex = sampler_state
{
	Texture = (mtlSkin1);
	AddressU = Clamp;
	AddressV = Clamp;
	
	MagFilter = Linear;
	MinFilter = Point;
	MipFilter = None;
};

sampler sBumpTex = sampler_state { Texture = (entSkin1); };


//////////////////////////////////////////////////////////////////////
//section: transform - calculate vertex position /////////////////////
float4 DoTransform(float4 Pos)
{
	return mul(Pos,matWorldViewProj);
}

struct out_water_env // Output to the pixelshader
{
	float4 Pos	: POSITION;
	
	float2 Tex0	: TEXCOORD0;	//Bumpmap
	float3 Tex2 : TEXCOORD1;
};

out_water_env vs_water_env
(
	float4 inPos		: POSITION,
	float3 inNormal	: NORMAL,
	float2 inTex0		: TEXCOORD0
)
{
	out_water_env Out;
	
	Out.Pos = DoTransform(inPos); // transform to screen coordinates
	
	// bump and reflection coordinates
	Out.Tex0.xy = (inTex0 + vecSkill41.xy * vecTime.w) * vecSkill41.w;
	
	Out.Tex2 = Out.Pos.xyw;
	
	return Out;
}


float4 PS_p0(	float2 Tex0 : TEXCOORD0, //Bumpmap
					float3 Tex2	: TEXCOORD1, //Reflection
					float4 Color : COLOR0
				) : COLOR 
{
	clip(vecSkill1.x);
	
	// die Bumpmap mit der waterCoord Koordinaten
	float4 Bump = tex2D(sBumpTex, Tex0.xy) * 2 - 1;
	
	//
	float2 CoordsRefl = 0.5*(1.0+Tex2.xy/Tex2.z)+Bump.xy*vecSkill41.z;
	
	// Reflektierte Wasseroberflche
	float4 reflection = tex2D(sReflectTex, CoordsRefl);
	
	reflection.a = 1.0;
	
	// Output
	return reflection;
}

//////////////////////////////////////////////////////////////////
technique water_env
{
	pass one
	{
		AlphaBlendEnable = True;
		ZEnable = True;
		ZWriteEnable=True;
		cullmode = none;
		
		VertexShader = compile vs_1_1 vs_water_env();
		PixelShader = compile ps_2_0 PS_p0();
	}
}

technique fallback { pass one { } }